@@ -22,12 +22,21 @@ use cPanel::APIClient;
 sub fail_if_returned_early { 1 }
 
 sub SKIP_CLASS {
-    my ($class) = @_;
+    my ($self) = @_;
 
-    my $classes_ar = mro::get_linear_isa($class);
+    my $classes_ar = mro::get_linear_isa(ref $self);
+
+    my %already;
 
     for my $class (@$classes_ar) {
-        my @reqs = $class->can('_CP_REQUIRE') ? $class->_CP_REQUIRE() : ();
+        my $cp_req_cr = $class->can('_CP_REQUIRE');
+
+        next if !$cp_req_cr;
+        next if $already{$cp_req_cr};
+
+        $already{$cp_req_cr} = 1;
+
+        my @reqs = $cp_req_cr->();
 
         for my $req (@reqs) {
             local $@;
